@@ -56,9 +56,21 @@ def get_args() -> Namespace:
         '-p', '--processes', type=int, metavar='n', default=cpu_count(),
         help='amount of parallel processes'
     )
+    parser.add_argument(
+        '-q', '--chunk-size', type=int, metavar='n',
+        help='chunk size for multiprocessing'
+    )
     parser.add_argument(
         '-s', '--shuffle', action='store_true', help='shuffle systems'
     )
+    parser.add_argument(
+        '-t', '--timeout', type=int, metavar='seconds', default=20*60,
+        help='seconds to wait for subprocesses to time out'
+    )
+    parser.add_argument(
+        '-u', '--user', metavar='name', default='root',
+        help='set the ssh user name'
+    )
     parser.add_argument(
         '-v', '--verbose', action='store_true', help='enable verbose logging'
     )
