@@ -14,7 +14,7 @@ __all__ = ['runcmd']
 def runcmd(system: int, args: Namespace) -> dict:
     """Runs commands on a remote system."""
 
-    command = ssh(system, args.execute, no_stdin=args.no_stdin)
+    command = ssh(system, args.execute, user=args.user, no_stdin=args.no_stdin)
     syslogger(system).debug('Running "%s" on system.', args.execute)
     completed_process = execute(command)
 
